import { Component, Vue, Prop } from 'vue-property-decorator';
import axios from 'axios';

const OssPrefix = 'https://horo-res.cdn.geektr.co/midorikawa-champion';

export interface Player {
  id: string;
  name: string;
  avatar: string;
}

export interface Group {
  name: string;
  members: Player[];
}

@Component
class ChampionData extends Vue {
  public ossPrefix = OssPrefix;
  public playerMap: { [s: string]: Player } = {};
  public groups: Group[] = [];
  public async load() {
    const { data } = await axios.get(`${OssPrefix}/index.json`);
    this.groups = data.groups;
    data.players.forEach(({ id, name }: Player) => {
      this.playerMap[id] = {
        id,
        name,
        avatar: `${OssPrefix}/avatar/${id}.jpg`,
      };
    });
  }
}

export default new ChampionData();
