const AliyunOssPlugin = require("aliyun-oss-plugin");
const SentryWebpackPlugin = require("@sentry/webpack-plugin");

const {
  NODE_ENV,
  ALIYUN_OSS_ACCESS_KEY_ID,
  ALIYUN_OSS_ACCESS_KEY_SECRET,
  ALIYUN_OSS_REGION,
  ALIYUN_OSS_BUCKET,
  SENTRY_DSN,
  CI_COMMIT_SHA = ""
} = process.env;

const pwaConf = {
  name: "Horo Club",
  themeColor: "#F5A623",
  msTileColor: "#444444"
};

const VUE_APP_RELEASE_CODE =
  CI_COMMIT_SHA.substr(0, 8) ||
  require("child_process")
    .execSync("git rev-parse HEAD")
    .toString()
    .substr(0, 8);

process.env.VUE_APP_RELEASE_CODE = VUE_APP_RELEASE_CODE;
process.env.VUE_APP_SENTRY_DSN = SENTRY_DSN;

const publicPath = "/";

if (NODE_ENV === "production") {
  module.exports = {
    publicPath: publicPath,
    configureWebpack: {
      plugins: [
        new AliyunOssPlugin({
          accessKeyId: ALIYUN_OSS_ACCESS_KEY_ID,
          accessKeySecret: ALIYUN_OSS_ACCESS_KEY_SECRET,
          region: ALIYUN_OSS_REGION,
          bucket: ALIYUN_OSS_BUCKET,
          headers: {
            "Cache-Control": "max-age=31536000"
          },
          ignore: ["**/*.js.map"]
        }),
        new SentryWebpackPlugin({
          include: "./dist",
          release: VUE_APP_RELEASE_CODE
        })
      ]
    },
    pwa: pwaConf
  };
} else {
  module.exports = {
    publicPath: publicPath,
    devServer: {
      progress: false
    },
    pwa: pwaConf
  };
}
